# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/74579/herpes/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/74579/herpes/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "74579\\Herpes\\": "packages/74579/herpes/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        74579\Herpes\Providers\HerpesServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Herpes'  => 74579\Herpes\Facades\Herpes::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=74579\\HerpesTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="74579\Herpes\Providers\HerpesServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="74579\Herpes\Providers\HerpesServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="74579\Herpes\Providers\HerpesServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/herpes/{modulename}

**User**

    http://path-to-route-folder/user/herpes/{modulename}

**Public**

    http://path-to-route-folder/herpes


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/herpes/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/herpes/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/herpes/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/herpes/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/herpes/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/herpes/{modulename}/{slug}
    METHOD: GET